import math


class Bernoulli:
    @staticmethod
    def bernoulli_probability(n, k, p):
        """
        Вычисление вероятности по формуле Бернулли.
        :param n: Количество испытаний
        :param k: Количество успехов
        :param p: Вероятность успеха
        :return: Вероятность ровно k успехов
        """
        coefficient = math.comb(n, k)
        return coefficient * (p ** k) * ((1 - p) ** (n - k))


class Bayes:
    @staticmethod
    def bayes_theorem(prior, likelihood, marginal):
        """
        Применение теоремы Байеса.
        :param prior: Априорная вероятность (P(A))
        :param likelihood: Условная вероятность (P(B|A))
        :param marginal: Маргинальная вероятность (P(B))
        :return: Результат применения теоремы Байеса (P(A|B))
        """
        return (prior * likelihood) / marginal


from setuptools import setup

setup(name='ter_ver_bb',
      version='0.0',
      description='The Bayes Formula and the Bernoulli Formula',
      packages=['ter_ver_bb'],
      author_email='poputnikov-egor1@mail.ru',
      zip_safe=False)
